@@ -1,8 +1,5 @@
 #!/usr/bin/env python
-import platform
-import sys
-
-from setuptools import setup
+from setuptools import find_packages, setup
 from setuptools_rust import RustExtension
 
 setup(
@@ -17,17 +14,13 @@ setup(
         "Operating System :: POSIX",
         "Operating System :: MacOS :: MacOS X",
     ],
-    packages=["rust_with_cffi"],
+    packages=find_packages(where="python"),
+    package_dir={"": "python"},
     rust_extensions=[
-        RustExtension(
-            "rust_with_cffi.rust",
-            py_limited_api=True,
-            features=[] if platform.python_implementation() == 'PyPy' else ["pyo3/abi3"]
-        ),
+        RustExtension("rust_with_cffi.rust", py_limited_api="auto"),
     ],
     cffi_modules=["cffi_module.py:ffi"],
     install_requires=["cffi"],
-    setup_requires=["cffi"],
     include_package_data=True,
     zip_safe=False,
 )
